@@ -5,16 +5,16 @@ use warnings;
 require Exporter ;
 use bytes;
 
-use IO::Compress::Base 2.096 ;
+use IO::Compress::Base 2.100 ;
 
-use IO::Compress::Base::Common  2.096 qw(isaScalar createSelfTiedObject);
-use IO::Compress::Adapter::LZO  2.096 ;
+use IO::Compress::Base::Common  2.100 qw(isaScalar createSelfTiedObject);
+use IO::Compress::Adapter::LZO  2.100 ;
 use Compress::LZO qw(crc32 adler32 LZO_VERSION);
-use IO::Compress::Lzop::Constants  2.096 ;
+use IO::Compress::Lzop::Constants  2.100 ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $LzopError);
 
-$VERSION = '2.096';
+$VERSION = '2.100';
 $LzopError = '';
 
 @ISA    = qw( IO::Compress::Base Exporter );
@@ -40,13 +40,13 @@ sub lzop
 #sub ckSum
 #{
 #    my $self = shift ;
-#    
+#
 #    return adler32($_[0]) if *$self->{LZOP}{Adler32} ;
 #    return crc32($_[0]) if *$self->{LZOP}{CRRC32} ;
 #    return '';
 #}
 
-sub mkHeader 
+sub mkHeader
 {
     my $self = shift ;
     my $param = shift ;
@@ -54,7 +54,7 @@ sub mkHeader
     my $filename = '';
 
     my $time = $param->getValue('time') ;
-    
+
     my $flags = F_OS_UNIX  ;
     if (! $param->getValue('minimal')) {
         $flags |= F_ADLER32_D | F_ADLER32_C ;
@@ -75,10 +75,10 @@ sub mkHeader
         $xtr .= $extra                    ; # Extra Data
         $xtr .= pack 'N', adler32($xtr)   ; # Extra CRC
     }
-    
+
     my $hdr = '' ;
 
-    $hdr .= pack 'n', 0x1010     ; # lzop Version 
+    $hdr .= pack 'n', 0x1010     ; # lzop Version
     $hdr .= pack 'n', 0x1080     ; # LZO library version
     $hdr .= pack 'n', 0x1010     ; # lzop extract version
     $hdr .= pack 'C', 1          ; # Method
@@ -107,14 +107,14 @@ sub ckParams
 {
     my $self = shift ;
     my $got = shift;
-    
+
     if (! $got->parsed('time') ) {
         # Modification time defaults to now.
         $got->setValue('time' => time) ;
     }
 
     #*$self->{LZOP}{Adler32} = ($got->getValue('??') ? 0 : 1) ;
-    
+
     return 1 ;
 }
 
@@ -133,8 +133,8 @@ sub mkComp
     return $self->saveErrorString(undef, $errstr, $errno)
         if ! defined $obj;
 
-    return $obj;    
-                                          
+    return $obj;
+
 }
 
 
@@ -164,7 +164,7 @@ our %PARAMS = (
     'blocksize' => [IO::Compress::Base::Common::Parse_unsigned,  BLOCK_SIZE],
     'optimize'  => [IO::Compress::Base::Common::Parse_boolean,   1],
 
-   # TODO 
+   # TODO
    #   none
    #   crc32
    #   adler32
@@ -185,8 +185,8 @@ sub getFileInfo
     my $self = shift ;
     my $params = shift;
     my $filename = shift ;
-    
-    return 
+
+    return
       if isaScalar($filename) ;
 
     my ($defaultMode, $defaultTime) = (stat($filename))[2, 9] ;
@@ -194,10 +194,10 @@ sub getFileInfo
     $params->setValue('name' => $filename)
         if ! $params->parsed('name') ;
 
-    $params->setValue('time' => $defaultTime) 
+    $params->setValue('time' => $defaultTime)
         if ! $params->parsed('time') ;
 
-    $params->setValue('mode' => $defaultMode) 
+    $params->setValue('mode' => $defaultMode)
         if ! $params->parsed('mode') ;
 }
 
@@ -216,7 +216,7 @@ IO::Compress::Lzop - Write lzop files/buffers
     my $status = lzop $input => $output [,OPTS]
         or die "lzop failed: $LzopError\n";
 
-    my $z = new IO::Compress::Lzop $output [,OPTS]
+    my $z = IO::Compress::Lzop->new( $output [,OPTS] )
         or die "lzop failed: $LzopError\n";
 
     $z->print($string);
@@ -499,7 +499,7 @@ compressed data to a buffer, C<$buffer>.
     use IO::Compress::Lzop qw(lzop $LzopError) ;
     use IO::File ;
 
-    my $input = new IO::File "<file1.txt"
+    my $input = IO::File->new( "<file1.txt" )
         or die "Cannot open 'file1.txt': $!\n" ;
     my $buffer ;
     lzop $input => \$buffer
@@ -536,7 +536,7 @@ and if you want to compress each file one at a time, this will do the trick
 
 The format of the constructor for C<IO::Compress::Lzop> is shown below
 
-    my $z = new IO::Compress::Lzop $output [,OPTS]
+    my $z = IO::Compress::Lzop->new( $output [,OPTS] )
         or die "IO::Compress::Lzop failed: $LzopError\n";
 
 It returns an C<IO::Compress::Lzop> object on success and undef on failure.
@@ -897,8 +897,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2020 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2021 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
-
